summaryrefslogtreecommitdiff
path: root/arch/x86/include/asm/e820/types.h
diff options
context:
space:
mode:
Diffstat (limited to 'arch/x86/include/asm/e820/types.h')
-rw-r--r--arch/x86/include/asm/e820/types.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/x86/include/asm/e820/types.h b/arch/x86/include/asm/e820/types.h
index e3171867e126..ae2c4e9db0d4 100644
--- a/arch/x86/include/asm/e820/types.h
+++ b/arch/x86/include/asm/e820/types.h
@@ -21,7 +21,7 @@
*
* This allows for bootstrap/firmware quirks such as possible duplicate
* E820 entries that might need room in the same arrays, prior to the
* call to sanitize_e820_array() to remove duplicates. The allowance
* of three memory map entries per node is "enough" entries for
* the initial hardware platform motivating this mechanism to make
* use of additional EFI map entries. Future platforms may want
@@ -68,7 +68,7 @@
/*
* The whole array of E820 entries:
*/
-struct e820_array {
+struct e820_table {
__u32 nr_map;
struct e820_entry map[E820_X_MAX];
};
@@ -21,7 +21,7 @@
* This allows for bootstrap/firmware quirks such as possible duplicate
* E820 entries that might need room in the same arrays, prior to the
- * call to sanitize_e820_array() to remove duplicates. The allowance
+ * call to sanitize_e820_table() to remove duplicates. The allowance
* of three memory map entries per node is "enough" entries for
* the initial hardware platform motivating this mechanism to make